# HelpDialog Widget for FLTK

Version 1.0 - October 12, 1999 - Michael Sweet

## Introduction

The `HelpDialog` widget displays HTML files and allows the user to click on links to do navigation.

## Source Code

The source code is provided under the terms of the GNU Library General Public License and is used to provide on-line help for the ESP Print Pro software.

You can download the source for the current version (1.0) in several formats:

- HelpDialog-1.0.tar.gz (34k)
- HelpDialog-1.0.zip (35k)

## Overview

The `HelpDialog` widget is based upon the `HelpView` widget which supports basic HTML elements including tables. Images and text alignment are not supported at this time, although the hooks are there for the alignment stuff.

To use the `HelpDialog` widget in your program do:

    #include "HelpDialog.h"

    ...

    {
      HelpView help();

      help.load("filename.html");
      help.show();
      while (help.visible())
        Fl::wait();
    }

## Methods

- `HelpDialog`
- `hide`
- `load`
- `show`
- `topline`
- `visible`

### HelpDialog::HelpDialog()

The constructor creates the dialog pictured above.

### void HelpDialog::hide()

Hides the `HelpDialog` window.

### void HelpDialog::load(const char *f)

Loads the specified HTML file into the `HelpView` widget. The filename can also contain a target name ("filename.html#target").

### void HelpDialog::show()

Shows the `HelpDialog` window.

### void HelpDialog::topline(const char *n)
void HelpDialog::topline(int n)

Sets the top line in the `HelpView` widget to the named or numbered line.

### int HelpDialog::visible()

Returns 1 if the `HelpDialog` window is visible.